import { MediaTypes } from '../types';
/**
 * This class allows access to the details of each outgoing invitation in a Conference
 * @link {Conference#getOutgoingInvitations()} method should be used to obtain the list
 * of instances of this class.
 * This is an immutable object, the private setters return a new object instance.
 */
export declare class Invitation {
    private to;
    private mediaTypes;
    private responseCode?;
    private _hasStreams;
    private canceled;
    private timestamp;
    /** @ignore */
    constructor(to: string, mediaTypes: MediaTypes, responseCode?: number | undefined, _hasStreams?: boolean, canceled?: boolean);
    /**
     * Obtains the "gateway username" of the invited user.
     */
    getTo(): string;
    /**
     * Obtains the mediaTypes for this invitation.
     * This allow us to guess if we are inviting the user with audio & video, or only with audio and video
     */
    getMediaTypes(): MediaTypes;
    /**
     * Returns The response code of the invitation.
     * This will be a 200 (OK) when the invited user accepts the invitation.
     */
    getResponseCode(): number | undefined;
    /**
     * Returns true when the conference room has a stream associated to the invited user.
     */
    hasStreams(): boolean;
    /**
     * Returns true when the user has cancelled this invitation.
     */
    isCanceled(): boolean;
    /**
     * Utility method that returns true when the invitation does not has a response code and it it not cancelled.
     */
    isActive(): boolean;
    /**
     * Returns the timestamp when this invitation object was created.
     * This is useful to keep the client showing the invitations with errors for a period of time.
     */
    getTimestamp(): number;
    /** @ignore */
    setTo(to: string): Invitation;
    /** @ignore */
    setResponseCode(responseCode: number): Invitation;
    /** @ignore */
    setCanceled(canceled: boolean): Invitation;
    /** @ignore */
    setStreams(hasStreams: boolean): Invitation;
}
